# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/billing/v1/budget.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/billing/v1/budget.proto',
  package='yandex.cloud.billing.v1',
  syntax='proto3',
  serialized_options=b'\n\033yandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billing',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$yandex/cloud/billing/v1/budget.proto\x12\x17yandex.cloud.billing.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\x86\x03\n\x06\x42udget\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1a\n\x12\x62illing_account_id\x18\x04 \x01(\t\x12\x35\n\x06status\x18\x05 \x01(\x0e\x32%.yandex.cloud.billing.v1.BudgetStatus\x12>\n\x0b\x63ost_budget\x18\x06 \x01(\x0b\x32\'.yandex.cloud.billing.v1.CostBudgetSpecH\x00\x12\x44\n\x0e\x65xpense_budget\x18\x07 \x01(\x0b\x32*.yandex.cloud.billing.v1.ExpenseBudgetSpecH\x00\x12\x44\n\x0e\x62\x61lance_budget\x18\x08 \x01(\x0b\x32*.yandex.cloud.billing.v1.BalanceBudgetSpecH\x00\x42\x13\n\x0b\x62udget_spec\x12\x04\xc0\xc1\x31\x01\"\xd7\x02\n\x0e\x43ostBudgetSpec\x12\x14\n\x06\x61mount\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12.\n\x1dnotification_user_account_ids\x18\x02 \x03(\tB\x07\x82\xc8\x31\x03>=1\x12?\n\x0fthreshold_rules\x18\x03 \x03(\x0b\x32&.yandex.cloud.billing.v1.ThresholdRule\x12:\n\x06\x66ilter\x18\x04 \x01(\x0b\x32*.yandex.cloud.billing.v1.ConsumptionFilter\x12@\n\x0creset_period\x18\x05 \x01(\x0e\x32(.yandex.cloud.billing.v1.ResetPeriodTypeH\x00\x12\x14\n\nstart_date\x18\x06 \x01(\tH\x00\x12\x16\n\x08\x65nd_date\x18\x07 \x01(\tB\x04\xe8\xc7\x31\x01\x42\x12\n\nstart_type\x12\x04\xc0\xc1\x31\x01\"\xda\x02\n\x11\x45xpenseBudgetSpec\x12\x14\n\x06\x61mount\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12.\n\x1dnotification_user_account_ids\x18\x02 \x03(\tB\x07\x82\xc8\x31\x03>=1\x12?\n\x0fthreshold_rules\x18\x03 \x03(\x0b\x32&.yandex.cloud.billing.v1.ThresholdRule\x12:\n\x06\x66ilter\x18\x04 \x01(\x0b\x32*.yandex.cloud.billing.v1.ConsumptionFilter\x12@\n\x0creset_period\x18\x05 \x01(\x0e\x32(.yandex.cloud.billing.v1.ResetPeriodTypeH\x00\x12\x14\n\nstart_date\x18\x06 \x01(\tH\x00\x12\x16\n\x08\x65nd_date\x18\x07 \x01(\tB\x04\xe8\xc7\x31\x01\x42\x12\n\nstart_type\x12\x04\xc0\xc1\x31\x01\"\xc6\x01\n\x11\x42\x61lanceBudgetSpec\x12\x14\n\x06\x61mount\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12.\n\x1dnotification_user_account_ids\x18\x02 \x03(\tB\x07\x82\xc8\x31\x03>=1\x12?\n\x0fthreshold_rules\x18\x03 \x03(\x0b\x32&.yandex.cloud.billing.v1.ThresholdRule\x12\x12\n\nstart_date\x18\x04 \x01(\t\x12\x16\n\x08\x65nd_date\x18\x05 \x01(\tB\x04\xe8\xc7\x31\x01\"\x7f\n\x11\x43onsumptionFilter\x12\x13\n\x0bservice_ids\x18\x01 \x03(\t\x12U\n\x15\x63loud_folders_filters\x18\x02 \x03(\x0b\x32\x36.yandex.cloud.billing.v1.CloudFoldersConsumptionFilter\"E\n\x1d\x43loudFoldersConsumptionFilter\x12\x10\n\x08\x63loud_id\x18\x01 \x01(\t\x12\x12\n\nfolder_ids\x18\x02 \x03(\t\"\x88\x01\n\rThresholdRule\x12:\n\x04type\x18\x01 \x01(\x0e\x32&.yandex.cloud.billing.v1.ThresholdTypeB\x04\xe8\xc7\x31\x01\x12\x14\n\x06\x61mount\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12%\n\x1dnotification_user_account_ids\x18\x03 \x03(\t*U\n\x0c\x42udgetStatus\x12\x1d\n\x19\x42UDGET_STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08\x46INISHED\x10\x03*\\\n\x0fResetPeriodType\x12!\n\x1dRESET_PERIOD_TYPE_UNSPECIFIED\x10\x00\x12\x0b\n\x07MONTHLY\x10\x01\x12\x0b\n\x07QUARTER\x10\x02\x12\x0c\n\x08\x41NNUALLY\x10\x03*H\n\rThresholdType\x12\x1e\n\x1aTHRESHOLD_TYPE_UNSPECIFIED\x10\x00\x12\x0b\n\x07PERCENT\x10\x01\x12\n\n\x06\x41MOUNT\x10\x02\x42\x62\n\x1byandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billingb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])

_BUDGETSTATUS = _descriptor.EnumDescriptor(
  name='BudgetStatus',
  full_name='yandex.cloud.billing.v1.BudgetStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BUDGET_STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FINISHED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1757,
  serialized_end=1842,
)
_sym_db.RegisterEnumDescriptor(_BUDGETSTATUS)

BudgetStatus = enum_type_wrapper.EnumTypeWrapper(_BUDGETSTATUS)
_RESETPERIODTYPE = _descriptor.EnumDescriptor(
  name='ResetPeriodType',
  full_name='yandex.cloud.billing.v1.ResetPeriodType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESET_PERIOD_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MONTHLY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='QUARTER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ANNUALLY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1844,
  serialized_end=1936,
)
_sym_db.RegisterEnumDescriptor(_RESETPERIODTYPE)

ResetPeriodType = enum_type_wrapper.EnumTypeWrapper(_RESETPERIODTYPE)
_THRESHOLDTYPE = _descriptor.EnumDescriptor(
  name='ThresholdType',
  full_name='yandex.cloud.billing.v1.ThresholdType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='THRESHOLD_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PERCENT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AMOUNT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1938,
  serialized_end=2010,
)
_sym_db.RegisterEnumDescriptor(_THRESHOLDTYPE)

ThresholdType = enum_type_wrapper.EnumTypeWrapper(_THRESHOLDTYPE)
BUDGET_STATUS_UNSPECIFIED = 0
CREATING = 1
ACTIVE = 2
FINISHED = 3
RESET_PERIOD_TYPE_UNSPECIFIED = 0
MONTHLY = 1
QUARTER = 2
ANNUALLY = 3
THRESHOLD_TYPE_UNSPECIFIED = 0
PERCENT = 1
AMOUNT = 2



_BUDGET = _descriptor.Descriptor(
  name='Budget',
  full_name='yandex.cloud.billing.v1.Budget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.billing.v1.Budget.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.billing.v1.Budget.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.billing.v1.Budget.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='billing_account_id', full_name='yandex.cloud.billing.v1.Budget.billing_account_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.billing.v1.Budget.status', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cost_budget', full_name='yandex.cloud.billing.v1.Budget.cost_budget', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expense_budget', full_name='yandex.cloud.billing.v1.Budget.expense_budget', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='balance_budget', full_name='yandex.cloud.billing.v1.Budget.balance_budget', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='budget_spec', full_name='yandex.cloud.billing.v1.Budget.budget_spec',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=130,
  serialized_end=520,
)


_COSTBUDGETSPEC = _descriptor.Descriptor(
  name='CostBudgetSpec',
  full_name='yandex.cloud.billing.v1.CostBudgetSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount', full_name='yandex.cloud.billing.v1.CostBudgetSpec.amount', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notification_user_account_ids', full_name='yandex.cloud.billing.v1.CostBudgetSpec.notification_user_account_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\003>=1', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='threshold_rules', full_name='yandex.cloud.billing.v1.CostBudgetSpec.threshold_rules', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.billing.v1.CostBudgetSpec.filter', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reset_period', full_name='yandex.cloud.billing.v1.CostBudgetSpec.reset_period', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_date', full_name='yandex.cloud.billing.v1.CostBudgetSpec.start_date', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_date', full_name='yandex.cloud.billing.v1.CostBudgetSpec.end_date', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='start_type', full_name='yandex.cloud.billing.v1.CostBudgetSpec.start_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=523,
  serialized_end=866,
)


_EXPENSEBUDGETSPEC = _descriptor.Descriptor(
  name='ExpenseBudgetSpec',
  full_name='yandex.cloud.billing.v1.ExpenseBudgetSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount', full_name='yandex.cloud.billing.v1.ExpenseBudgetSpec.amount', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notification_user_account_ids', full_name='yandex.cloud.billing.v1.ExpenseBudgetSpec.notification_user_account_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\003>=1', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='threshold_rules', full_name='yandex.cloud.billing.v1.ExpenseBudgetSpec.threshold_rules', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.billing.v1.ExpenseBudgetSpec.filter', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reset_period', full_name='yandex.cloud.billing.v1.ExpenseBudgetSpec.reset_period', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_date', full_name='yandex.cloud.billing.v1.ExpenseBudgetSpec.start_date', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_date', full_name='yandex.cloud.billing.v1.ExpenseBudgetSpec.end_date', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='start_type', full_name='yandex.cloud.billing.v1.ExpenseBudgetSpec.start_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=869,
  serialized_end=1215,
)


_BALANCEBUDGETSPEC = _descriptor.Descriptor(
  name='BalanceBudgetSpec',
  full_name='yandex.cloud.billing.v1.BalanceBudgetSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount', full_name='yandex.cloud.billing.v1.BalanceBudgetSpec.amount', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notification_user_account_ids', full_name='yandex.cloud.billing.v1.BalanceBudgetSpec.notification_user_account_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\003>=1', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='threshold_rules', full_name='yandex.cloud.billing.v1.BalanceBudgetSpec.threshold_rules', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_date', full_name='yandex.cloud.billing.v1.BalanceBudgetSpec.start_date', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_date', full_name='yandex.cloud.billing.v1.BalanceBudgetSpec.end_date', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1218,
  serialized_end=1416,
)


_CONSUMPTIONFILTER = _descriptor.Descriptor(
  name='ConsumptionFilter',
  full_name='yandex.cloud.billing.v1.ConsumptionFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_ids', full_name='yandex.cloud.billing.v1.ConsumptionFilter.service_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cloud_folders_filters', full_name='yandex.cloud.billing.v1.ConsumptionFilter.cloud_folders_filters', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1418,
  serialized_end=1545,
)


_CLOUDFOLDERSCONSUMPTIONFILTER = _descriptor.Descriptor(
  name='CloudFoldersConsumptionFilter',
  full_name='yandex.cloud.billing.v1.CloudFoldersConsumptionFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cloud_id', full_name='yandex.cloud.billing.v1.CloudFoldersConsumptionFilter.cloud_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_ids', full_name='yandex.cloud.billing.v1.CloudFoldersConsumptionFilter.folder_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1547,
  serialized_end=1616,
)


_THRESHOLDRULE = _descriptor.Descriptor(
  name='ThresholdRule',
  full_name='yandex.cloud.billing.v1.ThresholdRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yandex.cloud.billing.v1.ThresholdRule.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='yandex.cloud.billing.v1.ThresholdRule.amount', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notification_user_account_ids', full_name='yandex.cloud.billing.v1.ThresholdRule.notification_user_account_ids', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1619,
  serialized_end=1755,
)

_BUDGET.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BUDGET.fields_by_name['status'].enum_type = _BUDGETSTATUS
_BUDGET.fields_by_name['cost_budget'].message_type = _COSTBUDGETSPEC
_BUDGET.fields_by_name['expense_budget'].message_type = _EXPENSEBUDGETSPEC
_BUDGET.fields_by_name['balance_budget'].message_type = _BALANCEBUDGETSPEC
_BUDGET.oneofs_by_name['budget_spec'].fields.append(
  _BUDGET.fields_by_name['cost_budget'])
_BUDGET.fields_by_name['cost_budget'].containing_oneof = _BUDGET.oneofs_by_name['budget_spec']
_BUDGET.oneofs_by_name['budget_spec'].fields.append(
  _BUDGET.fields_by_name['expense_budget'])
_BUDGET.fields_by_name['expense_budget'].containing_oneof = _BUDGET.oneofs_by_name['budget_spec']
_BUDGET.oneofs_by_name['budget_spec'].fields.append(
  _BUDGET.fields_by_name['balance_budget'])
_BUDGET.fields_by_name['balance_budget'].containing_oneof = _BUDGET.oneofs_by_name['budget_spec']
_COSTBUDGETSPEC.fields_by_name['threshold_rules'].message_type = _THRESHOLDRULE
_COSTBUDGETSPEC.fields_by_name['filter'].message_type = _CONSUMPTIONFILTER
_COSTBUDGETSPEC.fields_by_name['reset_period'].enum_type = _RESETPERIODTYPE
_COSTBUDGETSPEC.oneofs_by_name['start_type'].fields.append(
  _COSTBUDGETSPEC.fields_by_name['reset_period'])
_COSTBUDGETSPEC.fields_by_name['reset_period'].containing_oneof = _COSTBUDGETSPEC.oneofs_by_name['start_type']
_COSTBUDGETSPEC.oneofs_by_name['start_type'].fields.append(
  _COSTBUDGETSPEC.fields_by_name['start_date'])
_COSTBUDGETSPEC.fields_by_name['start_date'].containing_oneof = _COSTBUDGETSPEC.oneofs_by_name['start_type']
_EXPENSEBUDGETSPEC.fields_by_name['threshold_rules'].message_type = _THRESHOLDRULE
_EXPENSEBUDGETSPEC.fields_by_name['filter'].message_type = _CONSUMPTIONFILTER
_EXPENSEBUDGETSPEC.fields_by_name['reset_period'].enum_type = _RESETPERIODTYPE
_EXPENSEBUDGETSPEC.oneofs_by_name['start_type'].fields.append(
  _EXPENSEBUDGETSPEC.fields_by_name['reset_period'])
_EXPENSEBUDGETSPEC.fields_by_name['reset_period'].containing_oneof = _EXPENSEBUDGETSPEC.oneofs_by_name['start_type']
_EXPENSEBUDGETSPEC.oneofs_by_name['start_type'].fields.append(
  _EXPENSEBUDGETSPEC.fields_by_name['start_date'])
_EXPENSEBUDGETSPEC.fields_by_name['start_date'].containing_oneof = _EXPENSEBUDGETSPEC.oneofs_by_name['start_type']
_BALANCEBUDGETSPEC.fields_by_name['threshold_rules'].message_type = _THRESHOLDRULE
_CONSUMPTIONFILTER.fields_by_name['cloud_folders_filters'].message_type = _CLOUDFOLDERSCONSUMPTIONFILTER
_THRESHOLDRULE.fields_by_name['type'].enum_type = _THRESHOLDTYPE
DESCRIPTOR.message_types_by_name['Budget'] = _BUDGET
DESCRIPTOR.message_types_by_name['CostBudgetSpec'] = _COSTBUDGETSPEC
DESCRIPTOR.message_types_by_name['ExpenseBudgetSpec'] = _EXPENSEBUDGETSPEC
DESCRIPTOR.message_types_by_name['BalanceBudgetSpec'] = _BALANCEBUDGETSPEC
DESCRIPTOR.message_types_by_name['ConsumptionFilter'] = _CONSUMPTIONFILTER
DESCRIPTOR.message_types_by_name['CloudFoldersConsumptionFilter'] = _CLOUDFOLDERSCONSUMPTIONFILTER
DESCRIPTOR.message_types_by_name['ThresholdRule'] = _THRESHOLDRULE
DESCRIPTOR.enum_types_by_name['BudgetStatus'] = _BUDGETSTATUS
DESCRIPTOR.enum_types_by_name['ResetPeriodType'] = _RESETPERIODTYPE
DESCRIPTOR.enum_types_by_name['ThresholdType'] = _THRESHOLDTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Budget = _reflection.GeneratedProtocolMessageType('Budget', (_message.Message,), {
  'DESCRIPTOR' : _BUDGET,
  '__module__' : 'yandex.cloud.billing.v1.budget_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.Budget)
  })
_sym_db.RegisterMessage(Budget)

CostBudgetSpec = _reflection.GeneratedProtocolMessageType('CostBudgetSpec', (_message.Message,), {
  'DESCRIPTOR' : _COSTBUDGETSPEC,
  '__module__' : 'yandex.cloud.billing.v1.budget_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.CostBudgetSpec)
  })
_sym_db.RegisterMessage(CostBudgetSpec)

ExpenseBudgetSpec = _reflection.GeneratedProtocolMessageType('ExpenseBudgetSpec', (_message.Message,), {
  'DESCRIPTOR' : _EXPENSEBUDGETSPEC,
  '__module__' : 'yandex.cloud.billing.v1.budget_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.ExpenseBudgetSpec)
  })
_sym_db.RegisterMessage(ExpenseBudgetSpec)

BalanceBudgetSpec = _reflection.GeneratedProtocolMessageType('BalanceBudgetSpec', (_message.Message,), {
  'DESCRIPTOR' : _BALANCEBUDGETSPEC,
  '__module__' : 'yandex.cloud.billing.v1.budget_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.BalanceBudgetSpec)
  })
_sym_db.RegisterMessage(BalanceBudgetSpec)

ConsumptionFilter = _reflection.GeneratedProtocolMessageType('ConsumptionFilter', (_message.Message,), {
  'DESCRIPTOR' : _CONSUMPTIONFILTER,
  '__module__' : 'yandex.cloud.billing.v1.budget_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.ConsumptionFilter)
  })
_sym_db.RegisterMessage(ConsumptionFilter)

CloudFoldersConsumptionFilter = _reflection.GeneratedProtocolMessageType('CloudFoldersConsumptionFilter', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDFOLDERSCONSUMPTIONFILTER,
  '__module__' : 'yandex.cloud.billing.v1.budget_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.CloudFoldersConsumptionFilter)
  })
_sym_db.RegisterMessage(CloudFoldersConsumptionFilter)

ThresholdRule = _reflection.GeneratedProtocolMessageType('ThresholdRule', (_message.Message,), {
  'DESCRIPTOR' : _THRESHOLDRULE,
  '__module__' : 'yandex.cloud.billing.v1.budget_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.ThresholdRule)
  })
_sym_db.RegisterMessage(ThresholdRule)


DESCRIPTOR._options = None
_BUDGET.oneofs_by_name['budget_spec']._options = None
_COSTBUDGETSPEC.oneofs_by_name['start_type']._options = None
_COSTBUDGETSPEC.fields_by_name['amount']._options = None
_COSTBUDGETSPEC.fields_by_name['notification_user_account_ids']._options = None
_COSTBUDGETSPEC.fields_by_name['end_date']._options = None
_EXPENSEBUDGETSPEC.oneofs_by_name['start_type']._options = None
_EXPENSEBUDGETSPEC.fields_by_name['amount']._options = None
_EXPENSEBUDGETSPEC.fields_by_name['notification_user_account_ids']._options = None
_EXPENSEBUDGETSPEC.fields_by_name['end_date']._options = None
_BALANCEBUDGETSPEC.fields_by_name['amount']._options = None
_BALANCEBUDGETSPEC.fields_by_name['notification_user_account_ids']._options = None
_BALANCEBUDGETSPEC.fields_by_name['end_date']._options = None
_THRESHOLDRULE.fields_by_name['type']._options = None
_THRESHOLDRULE.fields_by_name['amount']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datatransfer/v1/endpoint/clickhouse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yandex.cloud.datatransfer.v1.endpoint import common_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/datatransfer/v1/endpoint/clickhouse.proto',
  package='yandex.cloud.datatransfer.v1.endpoint',
  syntax='proto3',
  serialized_options=b'\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\252\002%Yandex.Cloud.Datatransfer.V1.EndPoint',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n6yandex/cloud/datatransfer/v1/endpoint/clickhouse.proto\x12%yandex.cloud.datatransfer.v1.endpoint\x1a\x1bgoogle/protobuf/empty.proto\x1a\x32yandex/cloud/datatransfer/v1/endpoint/common.proto\".\n\x0f\x43lickhouseShard\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05hosts\x18\x02 \x03(\t\"\xc7\x01\n\x13OnPremiseClickhouse\x12\x46\n\x06shards\x18\x01 \x03(\x0b\x32\x36.yandex.cloud.datatransfer.v1.endpoint.ClickhouseShard\x12\x11\n\thttp_port\x18\x03 \x01(\x03\x12\x13\n\x0bnative_port\x18\x04 \x01(\x03\x12@\n\x08tls_mode\x18\x08 \x01(\x0b\x32..yandex.cloud.datatransfer.v1.endpoint.TLSMode\"\xf5\x01\n\x1b\x43lickhouseConnectionOptions\x12\x18\n\x0emdb_cluster_id\x18\x05 \x01(\tH\x00\x12P\n\non_premise\x18\x02 \x01(\x0b\x32:.yandex.cloud.datatransfer.v1.endpoint.OnPremiseClickhouseH\x00\x12\x10\n\x08\x64\x61tabase\x18\x08 \x01(\t\x12\x0c\n\x04user\x18\x06 \x01(\t\x12?\n\x08password\x18\x07 \x01(\x0b\x32-.yandex.cloud.datatransfer.v1.endpoint.SecretB\t\n\x07\x61\x64\x64ress\"\x86\x01\n\x14\x43lickhouseConnection\x12`\n\x12\x63onnection_options\x18\x01 \x01(\x0b\x32\x42.yandex.cloud.datatransfer.v1.endpoint.ClickhouseConnectionOptionsH\x00\x42\x0c\n\nconnection\"\xcd\x04\n\x12\x43lickhouseSharding\x12\x66\n\x11\x63olumn_value_hash\x18\x01 \x01(\x0b\x32I.yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.ColumnValueHashH\x00\x12\x66\n\x0e\x63ustom_mapping\x18\x02 \x01(\x0b\x32L.yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.ColumnValueMappingH\x00\x12-\n\x0btransfer_id\x18\x03 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x1a&\n\x0f\x43olumnValueHash\x12\x13\n\x0b\x63olumn_name\x18\x01 \x01(\t\x1a\x83\x02\n\x12\x43olumnValueMapping\x12\x13\n\x0b\x63olumn_name\x18\x01 \x01(\t\x12j\n\x07mapping\x18\x02 \x03(\x0b\x32Y.yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.ColumnValueMapping.ValueToShard\x1al\n\x0cValueToShard\x12H\n\x0c\x63olumn_value\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.datatransfer.v1.endpoint.ColumnValue\x12\x12\n\nshard_name\x18\x02 \x01(\tB\n\n\x08sharding\"\xbf\x01\n\x10\x43lickhouseSource\x12O\n\nconnection\x18\x01 \x01(\x0b\x32;.yandex.cloud.datatransfer.v1.endpoint.ClickhouseConnection\x12\x11\n\tsubnet_id\x18\t \x01(\t\x12\x17\n\x0fsecurity_groups\x18\n \x03(\t\x12\x16\n\x0einclude_tables\x18\x07 \x03(\t\x12\x16\n\x0e\x65xclude_tables\x18\x08 \x03(\t\"\x98\x03\n\x10\x43lickhouseTarget\x12O\n\nconnection\x18\x02 \x01(\x0b\x32;.yandex.cloud.datatransfer.v1.endpoint.ClickhouseConnection\x12\x11\n\tsubnet_id\x18\x0c \x01(\t\x12\x17\n\x0fsecurity_groups\x18\x33 \x03(\t\x12\x1f\n\x17\x63lickhouse_cluster_name\x18\x32 \x01(\t\x12\x41\n\talt_names\x18\x11 \x03(\x0b\x32..yandex.cloud.datatransfer.v1.endpoint.AltName\x12K\n\x08sharding\x18\x16 \x01(\x0b\x32\x39.yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding\x12V\n\x0e\x63leanup_policy\x18\x15 \x01(\x0e\x32>.yandex.cloud.datatransfer.v1.endpoint.ClickhouseCleanupPolicy*\xb8\x01\n\x17\x43lickhouseCleanupPolicy\x12)\n%CLICKHOUSE_CLEANUP_POLICY_UNSPECIFIED\x10\x00\x12&\n\"CLICKHOUSE_CLEANUP_POLICY_DISABLED\x10\x01\x12\"\n\x1e\x43LICKHOUSE_CLEANUP_POLICY_DROP\x10\x02\x12&\n\"CLICKHOUSE_CLEANUP_POLICY_TRUNCATE\x10\x03\x42\xa7\x01\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\xaa\x02%Yandex.Cloud.Datatransfer.V1.EndPointb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2.DESCRIPTOR,])

_CLICKHOUSECLEANUPPOLICY = _descriptor.EnumDescriptor(
  name='ClickhouseCleanupPolicy',
  full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseCleanupPolicy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CLICKHOUSE_CLEANUP_POLICY_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLICKHOUSE_CLEANUP_POLICY_DISABLED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLICKHOUSE_CLEANUP_POLICY_DROP', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLICKHOUSE_CLEANUP_POLICY_TRUNCATE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2011,
  serialized_end=2195,
)
_sym_db.RegisterEnumDescriptor(_CLICKHOUSECLEANUPPOLICY)

ClickhouseCleanupPolicy = enum_type_wrapper.EnumTypeWrapper(_CLICKHOUSECLEANUPPOLICY)
CLICKHOUSE_CLEANUP_POLICY_UNSPECIFIED = 0
CLICKHOUSE_CLEANUP_POLICY_DISABLED = 1
CLICKHOUSE_CLEANUP_POLICY_DROP = 2
CLICKHOUSE_CLEANUP_POLICY_TRUNCATE = 3



_CLICKHOUSESHARD = _descriptor.Descriptor(
  name='ClickhouseShard',
  full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseShard',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseShard.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hosts', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseShard.hosts', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=178,
  serialized_end=224,
)


_ONPREMISECLICKHOUSE = _descriptor.Descriptor(
  name='OnPremiseClickhouse',
  full_name='yandex.cloud.datatransfer.v1.endpoint.OnPremiseClickhouse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='shards', full_name='yandex.cloud.datatransfer.v1.endpoint.OnPremiseClickhouse.shards', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_port', full_name='yandex.cloud.datatransfer.v1.endpoint.OnPremiseClickhouse.http_port', index=1,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='native_port', full_name='yandex.cloud.datatransfer.v1.endpoint.OnPremiseClickhouse.native_port', index=2,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tls_mode', full_name='yandex.cloud.datatransfer.v1.endpoint.OnPremiseClickhouse.tls_mode', index=3,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=227,
  serialized_end=426,
)


_CLICKHOUSECONNECTIONOPTIONS = _descriptor.Descriptor(
  name='ClickhouseConnectionOptions',
  full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseConnectionOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mdb_cluster_id', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseConnectionOptions.mdb_cluster_id', index=0,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='on_premise', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseConnectionOptions.on_premise', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseConnectionOptions.database', index=2,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseConnectionOptions.user', index=3,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseConnectionOptions.password', index=4,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='address', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseConnectionOptions.address',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=429,
  serialized_end=674,
)


_CLICKHOUSECONNECTION = _descriptor.Descriptor(
  name='ClickhouseConnection',
  full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseConnection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connection_options', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseConnection.connection_options', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='connection', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseConnection.connection',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=677,
  serialized_end=811,
)


_CLICKHOUSESHARDING_COLUMNVALUEHASH = _descriptor.Descriptor(
  name='ColumnValueHash',
  full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.ColumnValueHash',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='column_name', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.ColumnValueHash.column_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1091,
  serialized_end=1129,
)

_CLICKHOUSESHARDING_COLUMNVALUEMAPPING_VALUETOSHARD = _descriptor.Descriptor(
  name='ValueToShard',
  full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.ColumnValueMapping.ValueToShard',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='column_value', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.ColumnValueMapping.ValueToShard.column_value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shard_name', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.ColumnValueMapping.ValueToShard.shard_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1283,
  serialized_end=1391,
)

_CLICKHOUSESHARDING_COLUMNVALUEMAPPING = _descriptor.Descriptor(
  name='ColumnValueMapping',
  full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.ColumnValueMapping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='column_name', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.ColumnValueMapping.column_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mapping', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.ColumnValueMapping.mapping', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CLICKHOUSESHARDING_COLUMNVALUEMAPPING_VALUETOSHARD, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1132,
  serialized_end=1391,
)

_CLICKHOUSESHARDING = _descriptor.Descriptor(
  name='ClickhouseSharding',
  full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='column_value_hash', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.column_value_hash', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_mapping', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.custom_mapping', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transfer_id', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.transfer_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CLICKHOUSESHARDING_COLUMNVALUEHASH, _CLICKHOUSESHARDING_COLUMNVALUEMAPPING, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='sharding', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.sharding',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=814,
  serialized_end=1403,
)


_CLICKHOUSESOURCE = _descriptor.Descriptor(
  name='ClickhouseSource',
  full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connection', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSource.connection', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSource.subnet_id', index=1,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_groups', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSource.security_groups', index=2,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_tables', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSource.include_tables', index=3,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exclude_tables', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSource.exclude_tables', index=4,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1406,
  serialized_end=1597,
)


_CLICKHOUSETARGET = _descriptor.Descriptor(
  name='ClickhouseTarget',
  full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseTarget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connection', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseTarget.connection', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseTarget.subnet_id', index=1,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_groups', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseTarget.security_groups', index=2,
      number=51, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clickhouse_cluster_name', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseTarget.clickhouse_cluster_name', index=3,
      number=50, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alt_names', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseTarget.alt_names', index=4,
      number=17, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sharding', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseTarget.sharding', index=5,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cleanup_policy', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseTarget.cleanup_policy', index=6,
      number=21, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1600,
  serialized_end=2008,
)

_ONPREMISECLICKHOUSE.fields_by_name['shards'].message_type = _CLICKHOUSESHARD
_ONPREMISECLICKHOUSE.fields_by_name['tls_mode'].message_type = yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2._TLSMODE
_CLICKHOUSECONNECTIONOPTIONS.fields_by_name['on_premise'].message_type = _ONPREMISECLICKHOUSE
_CLICKHOUSECONNECTIONOPTIONS.fields_by_name['password'].message_type = yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2._SECRET
_CLICKHOUSECONNECTIONOPTIONS.oneofs_by_name['address'].fields.append(
  _CLICKHOUSECONNECTIONOPTIONS.fields_by_name['mdb_cluster_id'])
_CLICKHOUSECONNECTIONOPTIONS.fields_by_name['mdb_cluster_id'].containing_oneof = _CLICKHOUSECONNECTIONOPTIONS.oneofs_by_name['address']
_CLICKHOUSECONNECTIONOPTIONS.oneofs_by_name['address'].fields.append(
  _CLICKHOUSECONNECTIONOPTIONS.fields_by_name['on_premise'])
_CLICKHOUSECONNECTIONOPTIONS.fields_by_name['on_premise'].containing_oneof = _CLICKHOUSECONNECTIONOPTIONS.oneofs_by_name['address']
_CLICKHOUSECONNECTION.fields_by_name['connection_options'].message_type = _CLICKHOUSECONNECTIONOPTIONS
_CLICKHOUSECONNECTION.oneofs_by_name['connection'].fields.append(
  _CLICKHOUSECONNECTION.fields_by_name['connection_options'])
_CLICKHOUSECONNECTION.fields_by_name['connection_options'].containing_oneof = _CLICKHOUSECONNECTION.oneofs_by_name['connection']
_CLICKHOUSESHARDING_COLUMNVALUEHASH.containing_type = _CLICKHOUSESHARDING
_CLICKHOUSESHARDING_COLUMNVALUEMAPPING_VALUETOSHARD.fields_by_name['column_value'].message_type = yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2._COLUMNVALUE
_CLICKHOUSESHARDING_COLUMNVALUEMAPPING_VALUETOSHARD.containing_type = _CLICKHOUSESHARDING_COLUMNVALUEMAPPING
_CLICKHOUSESHARDING_COLUMNVALUEMAPPING.fields_by_name['mapping'].message_type = _CLICKHOUSESHARDING_COLUMNVALUEMAPPING_VALUETOSHARD
_CLICKHOUSESHARDING_COLUMNVALUEMAPPING.containing_type = _CLICKHOUSESHARDING
_CLICKHOUSESHARDING.fields_by_name['column_value_hash'].message_type = _CLICKHOUSESHARDING_COLUMNVALUEHASH
_CLICKHOUSESHARDING.fields_by_name['custom_mapping'].message_type = _CLICKHOUSESHARDING_COLUMNVALUEMAPPING
_CLICKHOUSESHARDING.fields_by_name['transfer_id'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_CLICKHOUSESHARDING.oneofs_by_name['sharding'].fields.append(
  _CLICKHOUSESHARDING.fields_by_name['column_value_hash'])
_CLICKHOUSESHARDING.fields_by_name['column_value_hash'].containing_oneof = _CLICKHOUSESHARDING.oneofs_by_name['sharding']
_CLICKHOUSESHARDING.oneofs_by_name['sharding'].fields.append(
  _CLICKHOUSESHARDING.fields_by_name['custom_mapping'])
_CLICKHOUSESHARDING.fields_by_name['custom_mapping'].containing_oneof = _CLICKHOUSESHARDING.oneofs_by_name['sharding']
_CLICKHOUSESHARDING.oneofs_by_name['sharding'].fields.append(
  _CLICKHOUSESHARDING.fields_by_name['transfer_id'])
_CLICKHOUSESHARDING.fields_by_name['transfer_id'].containing_oneof = _CLICKHOUSESHARDING.oneofs_by_name['sharding']
_CLICKHOUSESOURCE.fields_by_name['connection'].message_type = _CLICKHOUSECONNECTION
_CLICKHOUSETARGET.fields_by_name['connection'].message_type = _CLICKHOUSECONNECTION
_CLICKHOUSETARGET.fields_by_name['alt_names'].message_type = yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2._ALTNAME
_CLICKHOUSETARGET.fields_by_name['sharding'].message_type = _CLICKHOUSESHARDING
_CLICKHOUSETARGET.fields_by_name['cleanup_policy'].enum_type = _CLICKHOUSECLEANUPPOLICY
DESCRIPTOR.message_types_by_name['ClickhouseShard'] = _CLICKHOUSESHARD
DESCRIPTOR.message_types_by_name['OnPremiseClickhouse'] = _ONPREMISECLICKHOUSE
DESCRIPTOR.message_types_by_name['ClickhouseConnectionOptions'] = _CLICKHOUSECONNECTIONOPTIONS
DESCRIPTOR.message_types_by_name['ClickhouseConnection'] = _CLICKHOUSECONNECTION
DESCRIPTOR.message_types_by_name['ClickhouseSharding'] = _CLICKHOUSESHARDING
DESCRIPTOR.message_types_by_name['ClickhouseSource'] = _CLICKHOUSESOURCE
DESCRIPTOR.message_types_by_name['ClickhouseTarget'] = _CLICKHOUSETARGET
DESCRIPTOR.enum_types_by_name['ClickhouseCleanupPolicy'] = _CLICKHOUSECLEANUPPOLICY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClickhouseShard = _reflection.GeneratedProtocolMessageType('ClickhouseShard', (_message.Message,), {
  'DESCRIPTOR' : _CLICKHOUSESHARD,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.clickhouse_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.ClickhouseShard)
  })
_sym_db.RegisterMessage(ClickhouseShard)

OnPremiseClickhouse = _reflection.GeneratedProtocolMessageType('OnPremiseClickhouse', (_message.Message,), {
  'DESCRIPTOR' : _ONPREMISECLICKHOUSE,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.clickhouse_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.OnPremiseClickhouse)
  })
_sym_db.RegisterMessage(OnPremiseClickhouse)

ClickhouseConnectionOptions = _reflection.GeneratedProtocolMessageType('ClickhouseConnectionOptions', (_message.Message,), {
  'DESCRIPTOR' : _CLICKHOUSECONNECTIONOPTIONS,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.clickhouse_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.ClickhouseConnectionOptions)
  })
_sym_db.RegisterMessage(ClickhouseConnectionOptions)

ClickhouseConnection = _reflection.GeneratedProtocolMessageType('ClickhouseConnection', (_message.Message,), {
  'DESCRIPTOR' : _CLICKHOUSECONNECTION,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.clickhouse_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.ClickhouseConnection)
  })
_sym_db.RegisterMessage(ClickhouseConnection)

ClickhouseSharding = _reflection.GeneratedProtocolMessageType('ClickhouseSharding', (_message.Message,), {

  'ColumnValueHash' : _reflection.GeneratedProtocolMessageType('ColumnValueHash', (_message.Message,), {
    'DESCRIPTOR' : _CLICKHOUSESHARDING_COLUMNVALUEHASH,
    '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.clickhouse_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.ColumnValueHash)
    })
  ,

  'ColumnValueMapping' : _reflection.GeneratedProtocolMessageType('ColumnValueMapping', (_message.Message,), {

    'ValueToShard' : _reflection.GeneratedProtocolMessageType('ValueToShard', (_message.Message,), {
      'DESCRIPTOR' : _CLICKHOUSESHARDING_COLUMNVALUEMAPPING_VALUETOSHARD,
      '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.clickhouse_pb2'
      # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.ColumnValueMapping.ValueToShard)
      })
    ,
    'DESCRIPTOR' : _CLICKHOUSESHARDING_COLUMNVALUEMAPPING,
    '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.clickhouse_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.ColumnValueMapping)
    })
  ,
  'DESCRIPTOR' : _CLICKHOUSESHARDING,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.clickhouse_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding)
  })
_sym_db.RegisterMessage(ClickhouseSharding)
_sym_db.RegisterMessage(ClickhouseSharding.ColumnValueHash)
_sym_db.RegisterMessage(ClickhouseSharding.ColumnValueMapping)
_sym_db.RegisterMessage(ClickhouseSharding.ColumnValueMapping.ValueToShard)

ClickhouseSource = _reflection.GeneratedProtocolMessageType('ClickhouseSource', (_message.Message,), {
  'DESCRIPTOR' : _CLICKHOUSESOURCE,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.clickhouse_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.ClickhouseSource)
  })
_sym_db.RegisterMessage(ClickhouseSource)

ClickhouseTarget = _reflection.GeneratedProtocolMessageType('ClickhouseTarget', (_message.Message,), {
  'DESCRIPTOR' : _CLICKHOUSETARGET,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.clickhouse_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.ClickhouseTarget)
  })
_sym_db.RegisterMessage(ClickhouseTarget)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datatransfer/v1/endpoint/ydb.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/datatransfer/v1/endpoint/ydb.proto',
  package='yandex.cloud.datatransfer.v1.endpoint',
  syntax='proto3',
  serialized_options=b'\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\252\002%Yandex.Cloud.Datatransfer.V1.EndPoint',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/yandex/cloud/datatransfer/v1/endpoint/ydb.proto\x12%yandex.cloud.datatransfer.v1.endpoint\"\x9e\x01\n\tYdbSource\x12\x10\n\x08\x64\x61tabase\x18\x01 \x01(\t\x12\x10\n\x08instance\x18\x02 \x01(\t\x12\x1a\n\x12service_account_id\x18\x06 \x01(\t\x12\r\n\x05paths\x18\x05 \x03(\t\x12\x11\n\tsubnet_id\x18\x1e \x01(\t\x12\x17\n\x0fsecurity_groups\x18\" \x03(\t\x12\x16\n\x0esa_key_content\x18! \x01(\t\"\xee\x01\n\tYdbTarget\x12\x10\n\x08\x64\x61tabase\x18\x01 \x01(\t\x12\x10\n\x08instance\x18\x02 \x01(\t\x12\x1a\n\x12service_account_id\x18\x0b \x01(\t\x12\x0c\n\x04path\x18\n \x01(\t\x12\x11\n\tsubnet_id\x18\x1e \x01(\t\x12\x17\n\x0fsecurity_groups\x18! \x03(\t\x12\x16\n\x0esa_key_content\x18  \x01(\t\x12O\n\x0e\x63leanup_policy\x18\x15 \x01(\x0e\x32\x37.yandex.cloud.datatransfer.v1.endpoint.YdbCleanupPolicy*t\n\x10YdbCleanupPolicy\x12\"\n\x1eYDB_CLEANUP_POLICY_UNSPECIFIED\x10\x00\x12\x1f\n\x1bYDB_CLEANUP_POLICY_DISABLED\x10\x01\x12\x1b\n\x17YDB_CLEANUP_POLICY_DROP\x10\x02\x42\xa7\x01\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\xaa\x02%Yandex.Cloud.Datatransfer.V1.EndPointb\x06proto3'
)

_YDBCLEANUPPOLICY = _descriptor.EnumDescriptor(
  name='YdbCleanupPolicy',
  full_name='yandex.cloud.datatransfer.v1.endpoint.YdbCleanupPolicy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='YDB_CLEANUP_POLICY_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YDB_CLEANUP_POLICY_DISABLED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YDB_CLEANUP_POLICY_DROP', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=492,
  serialized_end=608,
)
_sym_db.RegisterEnumDescriptor(_YDBCLEANUPPOLICY)

YdbCleanupPolicy = enum_type_wrapper.EnumTypeWrapper(_YDBCLEANUPPOLICY)
YDB_CLEANUP_POLICY_UNSPECIFIED = 0
YDB_CLEANUP_POLICY_DISABLED = 1
YDB_CLEANUP_POLICY_DROP = 2



_YDBSOURCE = _descriptor.Descriptor(
  name='YdbSource',
  full_name='yandex.cloud.datatransfer.v1.endpoint.YdbSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='database', full_name='yandex.cloud.datatransfer.v1.endpoint.YdbSource.database', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instance', full_name='yandex.cloud.datatransfer.v1.endpoint.YdbSource.instance', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.datatransfer.v1.endpoint.YdbSource.service_account_id', index=2,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='paths', full_name='yandex.cloud.datatransfer.v1.endpoint.YdbSource.paths', index=3,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.datatransfer.v1.endpoint.YdbSource.subnet_id', index=4,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_groups', full_name='yandex.cloud.datatransfer.v1.endpoint.YdbSource.security_groups', index=5,
      number=34, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sa_key_content', full_name='yandex.cloud.datatransfer.v1.endpoint.YdbSource.sa_key_content', index=6,
      number=33, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=91,
  serialized_end=249,
)


_YDBTARGET = _descriptor.Descriptor(
  name='YdbTarget',
  full_name='yandex.cloud.datatransfer.v1.endpoint.YdbTarget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='database', full_name='yandex.cloud.datatransfer.v1.endpoint.YdbTarget.database', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instance', full_name='yandex.cloud.datatransfer.v1.endpoint.YdbTarget.instance', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.datatransfer.v1.endpoint.YdbTarget.service_account_id', index=2,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='yandex.cloud.datatransfer.v1.endpoint.YdbTarget.path', index=3,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.datatransfer.v1.endpoint.YdbTarget.subnet_id', index=4,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_groups', full_name='yandex.cloud.datatransfer.v1.endpoint.YdbTarget.security_groups', index=5,
      number=33, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sa_key_content', full_name='yandex.cloud.datatransfer.v1.endpoint.YdbTarget.sa_key_content', index=6,
      number=32, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cleanup_policy', full_name='yandex.cloud.datatransfer.v1.endpoint.YdbTarget.cleanup_policy', index=7,
      number=21, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=490,
)

_YDBTARGET.fields_by_name['cleanup_policy'].enum_type = _YDBCLEANUPPOLICY
DESCRIPTOR.message_types_by_name['YdbSource'] = _YDBSOURCE
DESCRIPTOR.message_types_by_name['YdbTarget'] = _YDBTARGET
DESCRIPTOR.enum_types_by_name['YdbCleanupPolicy'] = _YDBCLEANUPPOLICY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

YdbSource = _reflection.GeneratedProtocolMessageType('YdbSource', (_message.Message,), {
  'DESCRIPTOR' : _YDBSOURCE,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.ydb_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.YdbSource)
  })
_sym_db.RegisterMessage(YdbSource)

YdbTarget = _reflection.GeneratedProtocolMessageType('YdbTarget', (_message.Message,), {
  'DESCRIPTOR' : _YDBTARGET,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.ydb_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.YdbTarget)
  })
_sym_db.RegisterMessage(YdbTarget)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/agent/v1/test_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.loadtesting.agent.v1 import test_pb2 as yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_test__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/loadtesting/agent/v1/test_service.proto',
  package='yandex.cloud.loadtesting.agent.v1',
  syntax='proto3',
  serialized_options=b'\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agent',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4yandex/cloud/loadtesting/agent/v1/test_service.proto\x12!yandex.cloud.loadtesting.agent.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1dyandex/cloud/validation.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a,yandex/cloud/loadtesting/agent/v1/test.proto\"/\n\x0eGetTestRequest\x12\x1d\n\x07test_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xe3\x06\n\x11\x43reateTestRequest\x12\x1b\n\tfolder_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x91\x01\n\x06labels\x18\x04 \x03(\x0b\x32@.yandex.cloud.loadtesting.agent.v1.CreateTestRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12\x44\n\tgenerator\x18\x05 \x01(\x0e\x32\x31.yandex.cloud.loadtesting.agent.v1.Test.Generator\x12#\n\x11\x61gent_instance_id\x18\x06 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12$\n\x0etarget_address\x18\x07 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x13\n\x0btarget_port\x18\x08 \x01(\x03\x12 \n\x0etarget_version\x18\t \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x11\n\tinstances\x18\n \x01(\x03\x12\x42\n\rload_schedule\x18\x0b \x01(\x0b\x32+.yandex.cloud.loadtesting.agent.v1.Schedule\x12\x14\n\x06\x63onfig\x18\x0c \x01(\tB\x04\xe8\xc7\x31\x01\x12\x19\n\x07\x61mmo_id\x18\r \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1d\n\tammo_urls\x18\x0e \x03(\tB\n\x8a\xc8\x31\x06<=1024\x12\x14\n\x0c\x61mmo_headers\x18\x0f \x03(\t\x12>\n\tammo_type\x18\x10 \x01(\x0e\x32+.yandex.cloud.loadtesting.agent.v1.AmmoType\x12\x0b\n\x03ssl\x18\x11 \x01(\x08\x12\x17\n\x0fimbalance_point\x18\x12 \x01(\x03\x12\x14\n\x0cimbalance_ts\x18\x13 \x01(\x03\x12\x1c\n\x14logging_log_group_id\x18\x14 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"%\n\x12\x43reateTestMetadata\x12\x0f\n\x07test_id\x18\x01 \x01(\t\"\xf5\x03\n\x11UpdateTestRequest\x12\x1d\n\x07test_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x91\x01\n\x06labels\x18\x05 \x03(\x0b\x32@.yandex.cloud.loadtesting.agent.v1.UpdateTestRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12\x10\n\x08\x66\x61vorite\x18\x06 \x01(\x08\x12 \n\x0etarget_version\x18\x07 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x17\n\x0fimbalance_point\x18\x08 \x01(\x03\x12\x14\n\x0cimbalance_ts\x18\t \x01(\x03\x12\x19\n\x11imbalance_comment\x18\n \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"%\n\x12UpdateTestMetadata\x12\x0f\n\x07test_id\x18\x01 \x01(\t2\xfe\x03\n\x0bTestService\x12\x90\x01\n\x03Get\x12\x31.yandex.cloud.loadtesting.agent.v1.GetTestRequest\x1a\'.yandex.cloud.loadtesting.agent.v1.Test\"-\x82\xd3\xe4\x93\x02\'\x12%/loadtesting/agent/v1/tests/{test_id}\x12\xa7\x01\n\x06\x43reate\x12\x34.yandex.cloud.loadtesting.agent.v1.CreateTestRequest\x1a!.yandex.cloud.operation.Operation\"D\x82\xd3\xe4\x93\x02 \"\x1b/loadtesting/agent/v1/tests:\x01*\xb2\xd2*\x1a\n\x12\x43reateTestMetadata\x12\x04Test\x12\xb1\x01\n\x06Update\x12\x34.yandex.cloud.loadtesting.agent.v1.UpdateTestRequest\x1a!.yandex.cloud.operation.Operation\"N\x82\xd3\xe4\x93\x02*2%/loadtesting/agent/v1/tests/{test_id}:\x01*\xb2\xd2*\x1a\n\x12UpdateTestMetadata\x12\x04TestBt\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agentb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_test__pb2.DESCRIPTOR,])




_GETTESTREQUEST = _descriptor.Descriptor(
  name='GetTestRequest',
  full_name='yandex.cloud.loadtesting.agent.v1.GetTestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='test_id', full_name='yandex.cloud.loadtesting.agent.v1.GetTestRequest.test_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=306,
  serialized_end=353,
)


_CREATETESTREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.loadtesting.agent.v1.CreateTestRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.loadtesting.agent.v1.CreateTestRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.loadtesting.agent.v1.CreateTestRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1178,
  serialized_end=1223,
)

_CREATETESTREQUEST = _descriptor.Descriptor(
  name='CreateTestRequest',
  full_name='yandex.cloud.loadtesting.agent.v1.CreateTestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.loadtesting.agent.v1.CreateTestRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.loadtesting.agent.v1.CreateTestRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.loadtesting.agent.v1.CreateTestRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.loadtesting.agent.v1.CreateTestRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='generator', full_name='yandex.cloud.loadtesting.agent.v1.CreateTestRequest.generator', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='agent_instance_id', full_name='yandex.cloud.loadtesting.agent.v1.CreateTestRequest.agent_instance_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_address', full_name='yandex.cloud.loadtesting.agent.v1.CreateTestRequest.target_address', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_port', full_name='yandex.cloud.loadtesting.agent.v1.CreateTestRequest.target_port', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_version', full_name='yandex.cloud.loadtesting.agent.v1.CreateTestRequest.target_version', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instances', full_name='yandex.cloud.loadtesting.agent.v1.CreateTestRequest.instances', index=9,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='load_schedule', full_name='yandex.cloud.loadtesting.agent.v1.CreateTestRequest.load_schedule', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='yandex.cloud.loadtesting.agent.v1.CreateTestRequest.config', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ammo_id', full_name='yandex.cloud.loadtesting.agent.v1.CreateTestRequest.ammo_id', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ammo_urls', full_name='yandex.cloud.loadtesting.agent.v1.CreateTestRequest.ammo_urls', index=13,
      number=14, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1024', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ammo_headers', full_name='yandex.cloud.loadtesting.agent.v1.CreateTestRequest.ammo_headers', index=14,
      number=15, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ammo_type', full_name='yandex.cloud.loadtesting.agent.v1.CreateTestRequest.ammo_type', index=15,
      number=16, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ssl', full_name='yandex.cloud.loadtesting.agent.v1.CreateTestRequest.ssl', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='imbalance_point', full_name='yandex.cloud.loadtesting.agent.v1.CreateTestRequest.imbalance_point', index=17,
      number=18, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='imbalance_ts', full_name='yandex.cloud.loadtesting.agent.v1.CreateTestRequest.imbalance_ts', index=18,
      number=19, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='logging_log_group_id', full_name='yandex.cloud.loadtesting.agent.v1.CreateTestRequest.logging_log_group_id', index=19,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATETESTREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=356,
  serialized_end=1223,
)


_CREATETESTMETADATA = _descriptor.Descriptor(
  name='CreateTestMetadata',
  full_name='yandex.cloud.loadtesting.agent.v1.CreateTestMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='test_id', full_name='yandex.cloud.loadtesting.agent.v1.CreateTestMetadata.test_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1225,
  serialized_end=1262,
)


_UPDATETESTREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.loadtesting.agent.v1.UpdateTestRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.loadtesting.agent.v1.UpdateTestRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.loadtesting.agent.v1.UpdateTestRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1178,
  serialized_end=1223,
)

_UPDATETESTREQUEST = _descriptor.Descriptor(
  name='UpdateTestRequest',
  full_name='yandex.cloud.loadtesting.agent.v1.UpdateTestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='test_id', full_name='yandex.cloud.loadtesting.agent.v1.UpdateTestRequest.test_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.loadtesting.agent.v1.UpdateTestRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.loadtesting.agent.v1.UpdateTestRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.loadtesting.agent.v1.UpdateTestRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.loadtesting.agent.v1.UpdateTestRequest.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='favorite', full_name='yandex.cloud.loadtesting.agent.v1.UpdateTestRequest.favorite', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_version', full_name='yandex.cloud.loadtesting.agent.v1.UpdateTestRequest.target_version', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='imbalance_point', full_name='yandex.cloud.loadtesting.agent.v1.UpdateTestRequest.imbalance_point', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='imbalance_ts', full_name='yandex.cloud.loadtesting.agent.v1.UpdateTestRequest.imbalance_ts', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='imbalance_comment', full_name='yandex.cloud.loadtesting.agent.v1.UpdateTestRequest.imbalance_comment', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATETESTREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1265,
  serialized_end=1766,
)


_UPDATETESTMETADATA = _descriptor.Descriptor(
  name='UpdateTestMetadata',
  full_name='yandex.cloud.loadtesting.agent.v1.UpdateTestMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='test_id', full_name='yandex.cloud.loadtesting.agent.v1.UpdateTestMetadata.test_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1768,
  serialized_end=1805,
)

_CREATETESTREQUEST_LABELSENTRY.containing_type = _CREATETESTREQUEST
_CREATETESTREQUEST.fields_by_name['labels'].message_type = _CREATETESTREQUEST_LABELSENTRY
_CREATETESTREQUEST.fields_by_name['generator'].enum_type = yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_test__pb2._TEST_GENERATOR
_CREATETESTREQUEST.fields_by_name['load_schedule'].message_type = yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_test__pb2._SCHEDULE
_CREATETESTREQUEST.fields_by_name['ammo_type'].enum_type = yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_test__pb2._AMMOTYPE
_UPDATETESTREQUEST_LABELSENTRY.containing_type = _UPDATETESTREQUEST
_UPDATETESTREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATETESTREQUEST.fields_by_name['labels'].message_type = _UPDATETESTREQUEST_LABELSENTRY
DESCRIPTOR.message_types_by_name['GetTestRequest'] = _GETTESTREQUEST
DESCRIPTOR.message_types_by_name['CreateTestRequest'] = _CREATETESTREQUEST
DESCRIPTOR.message_types_by_name['CreateTestMetadata'] = _CREATETESTMETADATA
DESCRIPTOR.message_types_by_name['UpdateTestRequest'] = _UPDATETESTREQUEST
DESCRIPTOR.message_types_by_name['UpdateTestMetadata'] = _UPDATETESTMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetTestRequest = _reflection.GeneratedProtocolMessageType('GetTestRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTESTREQUEST,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.test_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.GetTestRequest)
  })
_sym_db.RegisterMessage(GetTestRequest)

CreateTestRequest = _reflection.GeneratedProtocolMessageType('CreateTestRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATETESTREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.loadtesting.agent.v1.test_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.CreateTestRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATETESTREQUEST,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.test_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.CreateTestRequest)
  })
_sym_db.RegisterMessage(CreateTestRequest)
_sym_db.RegisterMessage(CreateTestRequest.LabelsEntry)

CreateTestMetadata = _reflection.GeneratedProtocolMessageType('CreateTestMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATETESTMETADATA,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.test_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.CreateTestMetadata)
  })
_sym_db.RegisterMessage(CreateTestMetadata)

UpdateTestRequest = _reflection.GeneratedProtocolMessageType('UpdateTestRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATETESTREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.loadtesting.agent.v1.test_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.UpdateTestRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATETESTREQUEST,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.test_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.UpdateTestRequest)
  })
_sym_db.RegisterMessage(UpdateTestRequest)
_sym_db.RegisterMessage(UpdateTestRequest.LabelsEntry)

UpdateTestMetadata = _reflection.GeneratedProtocolMessageType('UpdateTestMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETESTMETADATA,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.test_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.UpdateTestMetadata)
  })
_sym_db.RegisterMessage(UpdateTestMetadata)


DESCRIPTOR._options = None
_GETTESTREQUEST.fields_by_name['test_id']._options = None
_CREATETESTREQUEST_LABELSENTRY._options = None
_CREATETESTREQUEST.fields_by_name['folder_id']._options = None
_CREATETESTREQUEST.fields_by_name['name']._options = None
_CREATETESTREQUEST.fields_by_name['description']._options = None
_CREATETESTREQUEST.fields_by_name['labels']._options = None
_CREATETESTREQUEST.fields_by_name['agent_instance_id']._options = None
_CREATETESTREQUEST.fields_by_name['target_address']._options = None
_CREATETESTREQUEST.fields_by_name['target_version']._options = None
_CREATETESTREQUEST.fields_by_name['config']._options = None
_CREATETESTREQUEST.fields_by_name['ammo_id']._options = None
_CREATETESTREQUEST.fields_by_name['ammo_urls']._options = None
_UPDATETESTREQUEST_LABELSENTRY._options = None
_UPDATETESTREQUEST.fields_by_name['test_id']._options = None
_UPDATETESTREQUEST.fields_by_name['name']._options = None
_UPDATETESTREQUEST.fields_by_name['description']._options = None
_UPDATETESTREQUEST.fields_by_name['labels']._options = None
_UPDATETESTREQUEST.fields_by_name['target_version']._options = None

_TESTSERVICE = _descriptor.ServiceDescriptor(
  name='TestService',
  full_name='yandex.cloud.loadtesting.agent.v1.TestService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1808,
  serialized_end=2318,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.loadtesting.agent.v1.TestService.Get',
    index=0,
    containing_service=None,
    input_type=_GETTESTREQUEST,
    output_type=yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_test__pb2._TEST,
    serialized_options=b'\202\323\344\223\002\'\022%/loadtesting/agent/v1/tests/{test_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.loadtesting.agent.v1.TestService.Create',
    index=1,
    containing_service=None,
    input_type=_CREATETESTREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002 \"\033/loadtesting/agent/v1/tests:\001*\262\322*\032\n\022CreateTestMetadata\022\004Test',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.loadtesting.agent.v1.TestService.Update',
    index=2,
    containing_service=None,
    input_type=_UPDATETESTREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002*2%/loadtesting/agent/v1/tests/{test_id}:\001*\262\322*\032\n\022UpdateTestMetadata\022\004Test',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TESTSERVICE)

DESCRIPTOR.services_by_name['TestService'] = _TESTSERVICE

# @@protoc_insertion_point(module_scope)
